@@ -3,7 +3,7 @@ use Evo '-Class::Gen::HUF GEN; -Class::Meta; -Class::Common meta_of';
 use Evo '-Export *, -import';
 
 export_proxy '-Class::Common',
-  qw(new:init has has_overriden requires extends implements with MODIFY_CODE_ATTRIBUTES);
+  qw(init has has_overriden requires extends implements with MODIFY_CODE_ATTRIBUTES);
 
 sub import ($me, @args) {
   my $caller = caller;
@@ -25,7 +25,7 @@ Evo::Class::Out
 
 =head1 VERSION
 
-version 0.0220
+version 0.0221
 
 =head1 DESCRIPTION
 
@@ -45,7 +45,7 @@ Makes possible to use any type of references as objects.
     has 'foo', required => 1;
   }
 
-  my $foo = My::Spy->init(sub { say "foo" }, foo => 'FOO');
+  my $foo = My::Spy::init(sub { say "foo" }, foo => 'FOO');
   say $foo->foo;
   $foo->();
 
@@ -57,6 +57,8 @@ C<Evo::Class::Out> supports the same features as C<Evo::Class::Hash>, but is a l
 
 Instead of C<new>, it provides C<init>. So you can desing new, for example, as a clousure by yourself
 
+Pay attention that C<init> should be called as a function C<My::Class::init>, not a method
+
 =head1 EXAMPLE
 
 In this example we created spy object, that logs all invocations. You can make the similar thing with overloading with the hash-class too, but this implementation has one advantage: it's a real C<codered> and C<reftype> returns C<CODE>, not C<HASH>.
