@@ -16,17 +16,6 @@ use constant HAS_SO_PROTOCOL  => eval { SO_PROTOCOL() && 1; 1 };
 
 export qw(CAN_BIND6 CAN_CHANGEV6ONLY HAS_REUSEPORT HAS_SO_DOMAIN HAS_SO_PROTOCOL);
 
-sub comp_meta : Export {
-  my %gen;
-  foreach my $what (qw(new gs)) {
-    $gen{$what} = sub {
-      sub {$what}
-    };
-  }
-
-  Evo::Class::Meta->new(gen => \%gen, rex => Evo::Role::Class->new());
-}
-
 sub dummy_meta : Export {
   my $class = shift || 'My::Dummy';
   my %gen;
@@ -36,7 +25,7 @@ sub dummy_meta : Export {
     };
   }
 
-  $gen{new} = sub($opts) {
+  $gen{init} = sub ($class, $opts) {
     sub {$opts}
   };
 
@@ -57,7 +46,7 @@ Test::Evo::Helpers
 
 =head1 VERSION
 
-version 0.0220
+version 0.0221
 
 =head1 AUTHOR
 
